@@ -8,7 +8,47 @@ import time
 from sqlalchemy import create_engine
 from sqlalchemy.exc import IntegrityError
 import mysql.connector
-from sqlalchemy import create_engine
+from cryptography.fernet import Fernet
+import pymysql
+
+"""# SAFFRONSTAYS - GET DATA FROM OUR DATABASE
+-- Run any SELECT query and get the result as a DataFrame
+
+```
+ss_sql_query( query , cypher_key )
+```
+"""
+
+
+def ss_sql_query(query,cypher_key):
+  # Returns a daframe object of the query response
+
+  key = bytes(cypher_key,'utf-8')
+  cipher_suite = Fernet(key)
+
+  host_enc = b'gAAAAABfQPr4eF5i5aU4vfC4RieOdLr9GjwQPWWmvTWT728cK-qUoPesPZmLKwE4vTkhh3oxCmREfrHN1omRwmxJJuo_CS4cMmRKG8_mLFIBQG1mg2Kx102PixJAdf1l74dhO6VI8ZCR'
+  user_enc = b'gAAAAABfQPr4PssChqSwFRHAGwKGCrKRLvnjRqfBkrazUydFvX3RBNAr5zAvKxdGJtaemdjq3uRwk1kgY4tLpIO9CxXj_JdC0w=='
+  pass_enc = b'gAAAAABfQPr4iwH0c5pxjI4XfV-uT-pBt9tKfQgFJEfjTcTIjwipeN4tI_bG-TtHoamosKEuFOldevYPi-3usIj1ZDSrb-zsXg=='
+  database_enc = b'gAAAAABfQPr48Sej-V7GarivuF4bsfBgP9rldzD500gl174HK4LZy70VfEob-kbaOBFa8rhuio_PbCFj4Nt3nJzVjKqC83d1NA=='
+
+  myServer = cipher_suite.decrypt(host_enc).decode("utf-8")
+  myUser = cipher_suite.decrypt(user_enc).decode("utf-8")
+  myPwd = cipher_suite.decrypt(pass_enc).decode("utf-8")
+  db = cipher_suite.decrypt(database_enc).decode("utf-8")
+
+  myConnection = pymysql.connect(host=myServer,user=myUser,password=myPwd,db=db)
+
+  if query.split(' ')[0] != 'SELECT':
+    return "Please only use non destructive (SELECT) queries."
+
+  response_df = pd.io.sql.read_sql(query, con=myConnection)
+
+  myConnection.close()
+
+  return response_df
+
+
+
 
 """# Vista APIs (Raw)  
 -- Lowest Level ( JSON API response, as is )
@@ -533,9 +573,4 @@ def final_test():
 
   return "All Good :)"
 
-"""# End"""
-
-
-
-
-
+"""# End"""
\ No newline at end of file
